// @shared/stores/editSightStore.ts
import { Language } from "@shared";
import { makeAutoObservable } from "mobx";

export interface MediaObject {
  id: string;
  filename: string;
  media_type: number;
}

type SightBaseInfo = {
  id: number;
  city_id: number;
  city: string;
  latitude: number;
  longitude: number;
  thumbnail: string;
  watermark_lu: string;
  watermark_rd: string;
  left_article: number;
  preview_media: string;
  video_preview: string;
};

export interface RightArticleBlock {
  id: string;
  type: "article" | "preview_media";
  name: string;
  linkedArticleId?: string;
  heading: string;
  body: string;
  media: MediaObject | null;
}

type SightInfo = SightBaseInfo & {
  [key in Language]: {
    info: {
      name: string;
      address: string;
    };
    left: {
      loaded: boolean; // Означает, что данные для этого языка были инициализированы/загружены
      heading: string;
      body: string;
      media: MediaObject | null;
    };
    right: RightArticleBlock[];
  };
};

class EditSightStore {
  sightInfo: SightInfo = {
    id: 0,
    city_id: 0,
    city: "",
    latitude: 0,
    longitude: 0,
    thumbnail: "",
    watermark_lu: "",
    watermark_rd: "",
    left_article: 0,
    preview_media: "",
    video_preview: "",
    ru: {
      info: { name: "", address: "" },
      left: { loaded: false, heading: "", body: "", media: null },
      right: [],
    },
    en: {
      info: { name: "", address: "" },
      left: { loaded: false, heading: "", body: "", media: null },
      right: [],
    },
    zh: {
      info: { name: "", address: "" },
      left: { loaded: false, heading: "", body: "", media: null },
      right: [],
    },
  };

  constructor() {
    makeAutoObservable(this);
  }

  // loadSightInfo: Используется для первоначальной загрузки данных для ЯЗЫКА.
  // Она устанавливает loaded: true, чтобы в будущем не перезатирать данные.
  loadSightInfo = (
    language: Language,
    heading: string,
    body: string,
    media: MediaObject | null
  ) => {
    // Важно: если данные уже были загружены или изменены, не перезаписывайте их.
    // Это предотвращает потерю пользовательского ввода при переключении языков.
    // Если хотите принудительную загрузку, добавьте другой метод или параметр.
    if (!this.sightInfo[language].left.loaded) {
      // <--- Только если еще не загружено
      this.sightInfo[language].left.heading = heading;
      this.sightInfo[language].left.body = body;
      this.sightInfo[language].left.media = media;
      this.sightInfo[language].left.loaded = true; // <--- Устанавливаем loaded только при загрузке
    }
  };

  // updateSightInfo: Используется для сохранения ЛЮБЫХ пользовательских изменений.
  // Она НЕ должна влиять на флаг 'loaded', который управляется 'loadSightInfo'.
  updateSightInfo = (
    language: Language,
    heading: string,
    body: string,
    media: MediaObject | null
  ) => {
    this.sightInfo[language].left.heading = heading;
    this.sightInfo[language].left.body = body;
    this.sightInfo[language].left.media = media;
    // this.sightInfo[language].left.loaded = true; // <-- УДАЛИТЕ эту строку
  };

  clearSightInfo = () => {
    this.sightInfo = {
      id: 0,
      city_id: 0,
      city: "",
      latitude: 0,
      longitude: 0,
      thumbnail: "",
      watermark_lu: "",
      watermark_rd: "",
      left_article: 0,
      preview_media: "",
      video_preview: "",
      ru: {
        info: { name: "", address: "" },
        left: { loaded: false, heading: "", body: "", media: null },
        right: [],
      },
      en: {
        info: { name: "", address: "" },
        left: { loaded: false, heading: "", body: "", media: null },
        right: [],
      },
      zh: {
        info: { name: "", address: "" },
        left: { loaded: false, heading: "", body: "", media: null },
        right: [],
      },
    };
  };
}

export const editSightStore = new EditSightStore();
